==> huaweicloudsdkdc-3.1.133-py2.py3-none-any.whl: huaweicloudsdkdc/v3/model/update_global_dc_gateway.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class UpdateGlobalDcGateway:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'name': 'str',
        'description': 'str',
        'address_family': 'str'
    }

    attribute_map = {
        'name': 'name',
        'description': 'description',
        'address_family': 'address_family'
    }

    def __init__(self, name=None, description=None, address_family=None):
        """UpdateGlobalDcGateway

        The model defined in huaweicloud sdk

        :param name: global-dc-gateway名字。
        :type name: str
        :param description: 描述信息。
        :type description: str
        :param address_family: global-dc-gateway的地址族
        :type address_family: str
        """
        
        

        self._name = None
        self._description = None
        self._address_family = None
        self.discriminator = None

        if name is not None:
            self.name = name
        if description is not None:
            self.description = description
        if address_family is not None:
            self.address_family = address_family

    @property
    def name(self):
        """Gets the name of this UpdateGlobalDcGateway.

        global-dc-gateway名字。

        :return: The name of this UpdateGlobalDcGateway.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this UpdateGlobalDcGateway.

        global-dc-gateway名字。

        :param name: The name of this UpdateGlobalDcGateway.
        :type name: str
        """
        self._name = name

    @property
    def description(self):
        """Gets the description of this UpdateGlobalDcGateway.

        描述信息。

        :return: The description of this UpdateGlobalDcGateway.
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this UpdateGlobalDcGateway.

        描述信息。

        :param description: The description of this UpdateGlobalDcGateway.
        :type description: str
        """
        self._description = description

    @property
    def address_family(self):
        """Gets the address_family of this UpdateGlobalDcGateway.

        global-dc-gateway的地址族

        :return: The address_family of this UpdateGlobalDcGateway.
        :rtype: str
        """
        return self._address_family

    @address_family.setter
    def address_family(self, address_family):
        """Sets the address_family of this UpdateGlobalDcGateway.

        global-dc-gateway的地址族

        :param address_family: The address_family of this UpdateGlobalDcGateway.
        :type address_family: str
        """
        self._address_family = address_family

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, UpdateGlobalDcGateway):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkdc-3.1.143-py2.py3-none-any.whl: huaweicloudsdkdc/v3/model/update_global_dc_gateway.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class UpdateGlobalDcGateway:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'name': 'str',
        'description': 'str',
        'address_family': 'str'
    }

    attribute_map = {
        'name': 'name',
        'description': 'description',
        'address_family': 'address_family'
    }

    def __init__(self, name=None, description=None, address_family=None):
        r"""UpdateGlobalDcGateway

        The model defined in huaweicloud sdk

        :param name: global-dc-gateway名字。
        :type name: str
        :param description: 描述信息。
        :type description: str
        :param address_family: global-dc-gateway的地址族
        :type address_family: str
        """
        
        

        self._name = None
        self._description = None
        self._address_family = None
        self.discriminator = None

        if name is not None:
            self.name = name
        if description is not None:
            self.description = description
        if address_family is not None:
            self.address_family = address_family

    @property
    def name(self):
        r"""Gets the name of this UpdateGlobalDcGateway.

        global-dc-gateway名字。

        :return: The name of this UpdateGlobalDcGateway.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        r"""Sets the name of this UpdateGlobalDcGateway.

        global-dc-gateway名字。

        :param name: The name of this UpdateGlobalDcGateway.
        :type name: str
        """
        self._name = name

    @property
    def description(self):
        r"""Gets the description of this UpdateGlobalDcGateway.

        描述信息。

        :return: The description of this UpdateGlobalDcGateway.
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        r"""Sets the description of this UpdateGlobalDcGateway.

        描述信息。

        :param description: The description of this UpdateGlobalDcGateway.
        :type description: str
        """
        self._description = description

    @property
    def address_family(self):
        r"""Gets the address_family of this UpdateGlobalDcGateway.

        global-dc-gateway的地址族

        :return: The address_family of this UpdateGlobalDcGateway.
        :rtype: str
        """
        return self._address_family

    @address_family.setter
    def address_family(self, address_family):
        r"""Sets the address_family of this UpdateGlobalDcGateway.

        global-dc-gateway的地址族

        :param address_family: The address_family of this UpdateGlobalDcGateway.
        :type address_family: str
        """
        self._address_family = address_family

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, UpdateGlobalDcGateway):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
